@@ -2,12 +2,11 @@
 use strict;
 use warnings;
 
-use lib '../lib';
-
+use lib '../lib/';
 use Math::Symbolic qw/:all/;
 use Math::Symbolic::VectorCalculus qw/:all/;
 
-my @gradient = grad 'x*y+2*z*x-y^2';
+my @gradient = grad 'x*y + 2*z*x - y^2';
 @gradient = map { $_->apply_derivatives()->simplify() } @gradient;
 print "$_\n" foreach @gradient;
 
@@ -36,4 +35,3 @@ foreach my $func (@matrix) {
     print "  ]\n";
 }
 print "]\n";
-
